@@ -2,6 +2,7 @@
     Core
 """
 
+# Core
 from .core import ID  # Scalar
 from .core import Controller  # Class
 from .core import Date  # Class
@@ -15,3 +16,6 @@ from .core import load  # Tool - Load
 from .core import text  # Scalar
 from .core import time  # Scalar
 from .core import type  # Type
+
+# Forms
+from .forms import Form as form
